﻿/*
The MIT License

Copyright (c) 2009-2010. Carlos Guzmán Álvarez. http://chronoswpf.codeplex.com/

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

using System;
using System.Threading.Tasks;
using Chronos.Authentication;
using Chronos.Presentation.Core.VirtualDesktops;
using Chronos.Presentation.MVVM.Services;
using nRoute.Components.Composition;
using nRoute.Components.Messaging;
using nRoute.Services;

namespace Chronos
{
    /// <summary>
    /// Dedicated observer for authentication 
    /// </summary>
    [MapChannelObserver(typeof(AuthenticationInfo),
        InitializationMode = InitializationMode.WhenAvailable,
        Lifetime = InstanceLifetime.Singleton)]
    public sealed class AuthenticationObserver : IObserver<AuthenticationInfo>
    {
        #region · IObserver<AuthenticationInfo> Members ·

        /// <summary>
        /// Notifies the observer that the provider has finished sending push-based notifications.
        /// </summary>
        public void OnCompleted()
        {
        }

        /// <summary>
        /// Notifies the observer that the provider has experienced an error condition.
        /// </summary>
        /// <param name="error">An object that provides additional information about the error.</param>
        public void OnError(Exception error)
        {
        }

        /// <summary>
        ///  Provides the observer with new data.
        /// </summary>
        /// <param name="value">The current notification information.</param>
        public void OnNext(AuthenticationInfo value)
        {
            switch (value.Action)
            {
                case AuthenticationAction.LogOn:
                    ServiceLocator.GetService<INavigationService>().NavigateTo("Chronos/LogIn");
                    break;

                case AuthenticationAction.LoggedIn:
                    ServiceLocator.GetService<IVirtualDesktopManager>().ActivateDefaultDesktop();
                    break;

                case AuthenticationAction.LogOut:
                    Task t = Task.Factory.StartNew(
                        () => 
                        {
                            ServiceLocator.GetService<IVirtualDesktopManager>().CloseAll();
                            Channel<AuthenticationInfo>.Publish(
                                new AuthenticationInfo { Action = AuthenticationAction.LogOn }, true);
                        });
                    break;
            }
        }

        #endregion
    }
}
