﻿using System;
using Chronos.Diagnostics.Contracts;
using nRoute.Components.Composition;
using nRoute.Services;
using Slf;

namespace Chronos.Diagnostics
{
    [MapService(typeof(ITraceService), 
        InitializationMode=InitializationMode.OnDemand,
        Lifetime=InstanceLifetime.Singleton)]
    public sealed class TraceService : ITraceService
    {
        #region · Static Members ·

        static readonly ILogger Logger = LoggerService.GetLogger();

        #endregion

        #region · Debug ·

        public void Debug(object obj)
        {
            Logger.Debug(obj);
        }

        public void Debug(string message)
        {
            Logger.Debug(message);
        }

        public void Debug(string format, params object[] args)
        {
            Logger.Debug(format, args);
        }

        public void Debug(IFormatProvider provider, string format, params object[] args)
        {
            Logger.Debug(provider, format, args);
        }

        public void Debug(Exception exception)
        {
            throw new NotImplementedException();
        }

        public void Debug(Exception exception, string message)
        {
            Logger.Debug(exception, message);
        }

        public void Debug(Exception exception, string format, params object[] args)
        {
            Logger.Debug(exception, format, args);
        }

        public void Debug(Exception exception, string format, IFormatProvider provider, params object[] args)
        {
            Logger.Debug(exception, format, provider, args);
        }

        #endregion

        #region · Info ·

        public void Info(object obj)
        {
            Logger.Info(obj);
        }

        public void Info(string message)
        {
            Logger.Info(message);
        }

        public void Info(string format, params object[] args)
        {
            Logger.Info(format, args);
        }

        public void Info(IFormatProvider provider, string format, params object[] args)
        {
            Logger.Info(provider, format, args);
        }

        public void Info(Exception exception)
        {
            Logger.Info(exception);
        }

        public void Info(Exception exception, string message)
        {
            Logger.Info(exception, message);
        }

        public void Info(Exception exception, string format, params object[] args)
        {
            Logger.Info(exception, format, args);
        }

        public void Info(Exception exception, string format, IFormatProvider provider, params object[] args)
        {
            Logger.Info(exception, format, provider, args);
        }

        #endregion

        #region · Warn ·

        public void Warn(object obj)
        {
            Logger.Warn(obj);
        }

        public void Warn(string message)
        {
            Logger.Warn(message);
        }

        public void Warn(string format, params object[] args)
        {
            Logger.Warn(format, args);
        }

        public void Warn(IFormatProvider provider, string format, params object[] args)
        {
            Logger.Warn(provider, format, args);
        }

        public void Warn(Exception exception)
        {
            Logger.Warn(exception);
        }

        public void Warn(Exception exception, string message)
        {
            Logger.Warn(exception, message);
        }

        public void Warn(Exception exception, string format, params object[] args)
        {
            Logger.Warn(exception, format, args);
        }

        public void Warn(Exception exception, string format, IFormatProvider provider, params object[] args)
        {
            Logger.Warn(exception, format, provider, args);
        }

        #endregion

        #region · Error ·

        public void Error(object obj)
        {
            Logger.Error(obj);
        }

        public void Error(string message)
        {
            Logger.Error(message);
        }

        public void Error(string format, params object[] args)
        {
            Logger.Error(format, args);
        }

        public void Error(IFormatProvider provider, string format, params object[] args)
        {
            Logger.Error(provider, format, args);
        }

        public void Error(Exception exception)
        {
            Logger.Error(exception);
        }

        public void Error(Exception exception, string message)
        {
            Logger.Error(exception, message);
        }

        public void Error(Exception exception, string format, params object[] args)
        {
            Logger.Error(exception, format, args);
        }

        public void Error(Exception exception, string format, IFormatProvider provider, params object[] args)
        {
            Logger.Error(exception, format, provider, args);
        }

        #endregion

        #region · Fatal ·

        public void Fatal(object obj)
        {
            Logger.Fatal(obj);
        }

        public void Fatal(string message)
        {
            Logger.Fatal(message);
        }

        public void Fatal(string format, params object[] args)
        {
            Logger.Fatal(format, args);
        }

        public void Fatal(IFormatProvider provider, string format, params object[] args)
        {
            Logger.Fatal(provider, format, args);
        }

        public void Fatal(Exception exception)
        {
            Logger.Fatal(exception);
        }

        public void Fatal(Exception exception, string message)
        {
            Logger.Fatal(exception, message);
        }

        public void Fatal(Exception exception, string format, params object[] args)
        {
            Logger.Fatal(exception, format, args);
        }

        public void Fatal(Exception exception, string format, IFormatProvider provider, params object[] args)
        {
            Logger.Fatal(exception, format, provider, args);
        }

        #endregion
    }
}
