﻿/*
The MIT License

Copyright (c) 2009-2010. Carlos Guzmán Álvarez. http://chronoswpf.codeplex.com/

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;

namespace Chronos.ExtensionMethods
{
    /// <summary>
    /// UIElement extension methods
    /// </summary>
    public static class UIElementExtensions
    {
        #region · Extension Methods ·

        /// <summary>
        /// Moves the specified element to the given position.
        /// </summary>
        /// <param name="element">The element.</param>
        /// <param name="position">The position.</param>
        public static void Move(this UIElement element, Point position)
        {
            element.Move(position.X, position.Y);
        }

        /// <summary>
        /// Moves the specified element to the given position.
        /// </summary>
        /// <param name="element">The element.</param>
        /// <param name="left">The left.</param>
        /// <param name="top">The top.</param>
        public static void Move(this UIElement element, double left, double top)
        {
            element.MoveLeft(left);
            element.MoveTop(top);
        }

        /// <summary>
        /// Moves the specified element to the given left position.
        /// </summary>
        /// <param name="element">The element.</param>
        /// <param name="left">The left.</param>
        public static void MoveLeft(this UIElement element, double left)
        {
            Canvas.SetLeft(element, left);
        }

        /// <summary>
        /// Moves the specified element to the given top position.
        /// </summary>
        /// <param name="element">The element.</param>
        /// <param name="top">The top.</param>
        public static void MoveTop(this UIElement element, double top)
        {
            Canvas.SetTop(element, top);
        }

        /// <summary>
        /// Sets the value of the ZIndex attached property for a given object. 
        /// </summary>
        /// <param name="element">The element.</param>
        /// <param name="zindex">The zindex.</param>
        public static void SetZIndex(this UIElement element, int zindex)
        {
            Canvas.SetZIndex(element, zindex);
        }

        /// <summary>
        /// Gets the parent.
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <param name="element">The element.</param>
        /// <returns></returns>
        public static T GetParent<T>(this UIElement element) where T: UIElement
        {
            // Walk the VisualTree to obtain the DesktopItem of the DragThumb
            DependencyObject parent = VisualTreeHelper.GetParent(element);

            while (parent != null && !(parent is T))
            {
                parent = VisualTreeHelper.GetParent(parent);
            }

            return parent as T;
        }

        /// <summary>
        /// Gets the canvas left position.
        /// </summary>
        /// <param name="element">The element.</param>
        /// <returns></returns>
        public static Point GetCanvasLeftPosition(this UIElement element)
        {
            return new Point(Canvas.GetLeft(element), Canvas.GetTop(element));
        }

        #endregion
    }
}
