﻿/*
The MIT License

Copyright (c) 2009-2010. Carlos Guzmán Álvarez. http://chronoswpf.codeplex.com/

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

using System.Windows;
using System.Windows.Media;
using System.Windows.Media.Imaging;

namespace Chronos.ExtensionMethods
{
    /// <summary>
    /// Visual Extension Methods
    /// </summary>
    /// <remarks>
    /// http://blogs.msdn.com/jaimer/
    /// </remarks>
    public static class VisualExtensions
    {
        #region · Static Members ·

        static readonly Point   DefaultPoint    = new Point(0, 0);
        static readonly double  DpiX            = 96.0;
        static readonly double  DpiY            = 96.0;

        #endregion

        #region · Extension Methods ·

        /// <summary>
        /// Captures an screenshot of the given Visual
        /// </summary>
        /// <param name="target">The target.</param>
        /// <returns></returns>
        public static BitmapSource CaptureScreen(this Visual target)
        {
            return CaptureScreen(target, DpiX, DpiY);
        }

        /// <summary>
        /// Captures an screenshot of the given Visual
        /// </summary>
        /// <param name="target">The target.</param>
        /// <param name="dpiX">The dpi X.</param>
        /// <param name="dpiY">The dpi Y.</param>
        /// <returns></returns>
        public static BitmapSource CaptureScreen(this Visual target, double dpiX, double dpiY)
        {
            if (target == null)
            {
                return null;
            }

            DrawingVisual       dv      = new DrawingVisual();
            Rect                bounds  = VisualTreeHelper.GetDescendantBounds(target);
            RenderTargetBitmap  rtb     = new RenderTargetBitmap((int)(bounds.Width * dpiX / DpiX),
                                                                 (int)(bounds.Height * dpiY / DpiY),
                                                                 dpiX,
                                                                 dpiY,
                                                                 PixelFormats.Pbgra32);

            using (DrawingContext ctx = dv.RenderOpen())
            {
                ctx.DrawRectangle(new VisualBrush(target), null, new Rect(DefaultPoint, bounds.Size));
            }

            rtb.Render(dv);

            return rtb;
        }

        #endregion
    }
}
