﻿/*
The MIT License

Copyright (c) 2009-2010. Carlos Guzmán Álvarez. http://chronoswpf.codeplex.com/

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

using System;
using System.Collections.ObjectModel;
using System.Windows;
using Chronos.Presentation.MVVM;

namespace Chronos.Presentation.Core.VirtualDesktops
{
    /// <summary>
    /// Interface for virtual desktop implementations
    /// </summary>
    public interface IVirtualDesktop
    {
        #region · Properties ·

        /// <summary>
        /// Gets the desktop 
        /// </summary>
        Guid Id
        {
            get;
        }

        /// <summary>
        /// Gets the list of active Windows
        /// </summary>
        ReadOnlyObservableCollection<ITrackableWindow> ActiveWindows
        {
            get;
        }

        #endregion

        #region · Methods ·

        /// <summary>
        /// Activates the desktop instance
        /// </summary>
        void Activate();

        /// <summary>
        /// Deactivates the desktop instance
        /// </summary>
        void Deactivate();
        
        /// <summary>
        /// Saves the desktop to disk
        /// </summary>
        void Save();

        /// <summary>
        /// Creates a new shortcut with the given display name and target
        /// </summary>
        /// <param name="displayName"></param>
        /// <param name="target"></param>
        void CreateShortcut(string displayName, string target);

        /// <summary>
        /// Shows the specified shortcut.
        /// </summary>
        /// <param name="shortcut">The shortcut.</param>
        void Show(ShortcutViewModelBase shortcut);

        /// <summary>
        /// Shows the specified shortcut.
        /// </summary>
        /// <param name="shortcut">The shortcut.</param>
        /// <param name="position">The position.</param>
        void Show(ShortcutViewModelBase shortcut, Point position);

        /// <summary>
        /// Shows the specified widget.
        /// </summary>
        /// <param name="widget">The widget.</param>
        void Show(WidgetViewModel widget);

        /// <summary>
        /// Shows the specified widget.
        /// </summary>
        /// <param name="widget">The widget.</param>
        /// <param name="position">The position.</param>
        void Show(WidgetViewModel widget, Point position);

        /// <summary>
        /// Close the given element
        /// </summary>
        /// <param name="element"></param>
        void Close(ClosableViewModel element);

        /// <summary>
        /// Closes the element with the given Id
        /// </summary>
        /// <param name="id">The id.</param>
        void Close(Guid id);

        /// <summary>
        /// Closes all the elements
        /// </summary>
        /// <param name="id">The id.</param>
        void CloseAll();

        /// <summary>
        /// Shows the given <see cref="UIElement"/> as a normal Window
        /// </summary>
        /// <param name="window"></param>
        /// <remarks>The UIElement should inherit from <see cref="WindowElement"/></remarks>
        void Show(UIElement element);

        /// <summary>
        /// Restores the window with the given Id
        /// </summary>
        /// <param name="id"></param>
        void Restore(Guid id);

        #endregion
    }
}
