﻿/*
The MIT License

Copyright (c) 2009-2010. Carlos Guzmán Álvarez. http://chronoswpf.codeplex.com/

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

using System;
using Chronos.Presentation.MVVM.Messaging;
using Chronos.Presentation.MVVM.Services;
using nRoute.Components;
using nRoute.Components.Messaging;
using nRoute.ViewServices;

namespace Chronos.Presentation.MVVM
{
    /// <summary>
    /// Base class for shortcut viewmodel implementations
    /// </summary>
    public abstract class ShortcutViewModelBase : ClosableViewModel
    {
        #region · Fields ·
        
        private ActionCommand openCommand;

        #endregion

        #region · Commands ·

        /// <summary>
        /// Gets the open command.
        /// </summary>
        /// <value>The open command.</value>
        public ActionCommand OpenCommand
        {
            get
            {
                if (this.openCommand == null)
                {
                    this.openCommand = new ActionCommand(() => OnOpen());
                }

                return this.openCommand;
            }
        }

        #endregion

        #region · Properties ·

        public abstract string IconStyle
        {
            get;
            set;
        }

        #endregion

        #region · Constructors ·

        /// <summary>
        /// Initializes a new instance of the <see cref="ShortcutViewModelBase"/> class.
        /// </summary>
        protected ShortcutViewModelBase()
            : base()
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="ShortcutViewModelBase"/> class.
        /// </summary>
        protected ShortcutViewModelBase(string displayName)
            : base(displayName)
        {
        }

        #endregion

        #region · Command Actions ·

        /// <summary>
        /// Called when the <see cref="OpenCommand"/>  is executed.
        /// </summary>
        protected abstract void OnOpen();

        /// <summary>
        /// Called when the related view is being closed.
        /// </summary>
        protected override void  OnCloseView()
        {
            IShowMessageViewService showMessageService = ViewServiceLocator.GetViewService<IShowMessageViewService>();

            showMessageService.ButtonSetup  = DialogButton.YesNo;
            showMessageService.Caption      = "Delete Shortcut";
            showMessageService.Text         = 
                String.Format(
                    "¿Are you sure you want to permanently delete this shortcut? {0}{1}", 
                        Environment.NewLine,
                            this.DisplayName);

            if (showMessageService.ShowMessage() == DialogResult.Yes)
            {
                Channel<DesktopElementActionInfo>.Publish(
                    new DesktopElementActionInfo { Id = this.Id, Action = DesktopElementAction.Close }, true);
            }
        }

        #endregion
    }
}
