﻿/*
The MIT License

Copyright (c) 2009-2010. Carlos Guzmán Álvarez. http://chronoswpf.codeplex.com/

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;

namespace Chronos.Presentation.Windows.Controls
{
    /// <summary>
    /// Provides the ability to display shortcuts in a <see cref="Desktop"/> control.
    /// </summary>
    public sealed class ShortcutElement : DesktopElement 
    {
        #region · Static Constructors ·

        /// <summary>
        /// Initializes the <see cref="ShortcutElement"/> class.
        /// </summary>
        static ShortcutElement()
        {
            // set the key to reference the style for this control
            FrameworkElement.DefaultStyleKeyProperty.OverrideMetadata(
                typeof(ShortcutElement), new FrameworkPropertyMetadata(typeof(ShortcutElement)));

            FocusManager.IsFocusScopeProperty.OverrideMetadata(
                typeof(ShortcutElement), new FrameworkPropertyMetadata(true));

            Control.IsTabStopProperty.OverrideMetadata(typeof(ShortcutElement),
                new FrameworkPropertyMetadata(false));

            KeyboardNavigation.DirectionalNavigationProperty.OverrideMetadata(
                typeof(ShortcutElement), new FrameworkPropertyMetadata(KeyboardNavigationMode.None));

            KeyboardNavigation.TabNavigationProperty.OverrideMetadata(
                typeof(ShortcutElement), new FrameworkPropertyMetadata(KeyboardNavigationMode.None));

            KeyboardNavigation.ControlTabNavigationProperty.OverrideMetadata(
                typeof(ShortcutElement), new FrameworkPropertyMetadata(KeyboardNavigationMode.None));
        }

        #endregion

        #region · Constructors ·

        /// <summary>
        /// Initializes a new instance of the <see cref="ShortcutElement"/> class.
        /// </summary>
        public ShortcutElement()
            : base()
        {
        }

        #endregion
    }
}
