﻿/*
The MIT License

Copyright (c) 2009-2010. Carlos Guzmán Álvarez. http://chronoswpf.codeplex.com/

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

using System;
using Chronos.Presentation.MVVM.Services;
using Chronos.Presentation.Windows.Controls;
using nRoute.Components.Composition;
using nRoute.ViewServices;

namespace Chronos.Presentation.Windows.ViewServices
{
    [MapViewService(typeof(IShowMessageViewService), ShowMessageViewService.SERVICE_NAME,
            InitializationMode = InitializationMode.OnDemand, Lifetime = ViewServiceLifetime.PerInstance)]
    public sealed class ShowMessageViewService
        : IShowMessageViewService
    {
        #region · Constants ·

        const string SERVICE_NAME = "ChronosMessageBoxViewService";

        #endregion

        #region · Properties ·

        /// <summary>
        /// Gets or sets the message caption
        /// </summary>
        /// <value></value>
        public string Caption
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the message text
        /// </summary>
        /// <value></value>
        public string Text
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the message buttons
        /// </summary>
        /// <value></value>
        public DialogButton ButtonSetup
        {
            get;
            set;
        }

        #endregion

        #region · Constructors ·

        /// <summary>
        /// Initializes a new instance of the <see cref="ShowMessageViewService"/> class.
        /// </summary>
        public ShowMessageViewService()
        {
        }

        #endregion

        #region · Methods ·

        /// <summary>
        /// Shows a new message window
        /// </summary>
        /// <returns></returns>
        public DialogResult ShowMessage()
        {
            return MessageWindowElement.Show(this.Caption ?? String.Empty, this.Text, this.ButtonSetup);
        }

        #endregion
    }
}
