﻿/*
The MIT License

Copyright (c) 2009-2010. Carlos Guzmán Álvarez. http://chronoswpf.codeplex.com/

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

using System;
using System.Windows;
using Chronos.Authentication;
using Chronos.Presentation.Core.VirtualDesktops;
using Chronos.Presentation.MVVM;
using nRoute.Components;
using nRoute.Components.Messaging;
using nRoute.Services;

namespace Chronos.ViewModel
{
    /// <summary>
    /// Login view view model class
    /// </summary>
    public sealed class LoginViewModel : ClosableViewModel
    {
        #region · Fields ·

        private string        userName;
        private string        userPassword;
        private ActionCommand acceptCommand;

        #endregion

        #region · Commands ·

        /// <summary>
        /// Gets the accept command
        /// </summary>
        public ActionCommand AcceptCommand
        {
            get
            {
                if (this.acceptCommand == null)
                {
                    this.acceptCommand = new ActionCommand(() => OnAccept(), () => CanAccept());
                }

                return this.acceptCommand;
            }
        }

        #endregion

        #region · Properties ·

        /// <summary>
        /// Gets or sets the user name
        /// </summary>
        public string UserName
        {
            get { return this.userName; }
            set
            {
                if (this.userName != value)
                {
                    this.userName = value;
                    this.NotifyPropertyChanged(() => UserName);

                    this.AcceptCommand.RequeryCanExecute();
                }
            }
        }

        /// <summary>
        /// Gets or sets the user password
        /// </summary>
        public string UserPassword
        {
            get { return this.userPassword; }
            set
            {
                if (this.userPassword != value)
                {
                    this.userPassword = value;
                    this.NotifyPropertyChanged(() => UserPassword);

                    this.AcceptCommand.RequeryCanExecute();
                }
            }
        }

        /// <summary>
        /// Gets the display name
        /// </summary>
        public override string DisplayName
        {
            get { return "LogIn"; }
        }

        #endregion

        #region · Constructors ·

        /// <summary>
        /// Initializes a new instance of the <see cref="LoginViewModel"/> class
        /// </summary>
        public LoginViewModel() 
            : base()
        {
        }

        #endregion

        #region · Command Actions ·

        private bool CanCloseWindow()
        {
            return true;
        }

        protected override void OnCloseView()
        {
            Application.Current.Shutdown();
        }

        private bool CanAccept()
        {
            return !String.IsNullOrEmpty(this.UserName) && !String.IsNullOrEmpty(this.UserPassword);
        }

        private void OnAccept()
        {
            Channel<AuthenticationInfo>.Publish(
                new AuthenticationInfo 
                { 
                    Action = AuthenticationAction.LoggedIn, 
                    UserName = this.UserName 
                }, true);

            ServiceLocator.GetService<IVirtualDesktopManager>().CloseDialog();
        }

        #endregion
    }
}
