﻿/*
The MIT License

Copyright (c) 2009-2010. Carlos Guzmán Álvarez. http://chronoswpf.codeplex.com/

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

using nRoute.Components;
using nRoute.Navigation;

namespace Chronos.Presentation.Core.ViewModel
{
    /// <summary>
    /// Interface for navigation viewmodel implementations
    /// </summary>
    public interface INavigationViewModel 
        : IClosableViewModel, ISupportNavigationLifecycle, ISupportNavigationState
    {
        #region · Commands ·

        /// <summary>
        /// Gets the open new window command
        /// </summary>
        ActionCommand NewWindowCommand
        {
            get;
        }

        /// <summary>
        /// Gets the restore window command.
        /// </summary>
        /// <value>The restore window command.</value>
        ActionCommand RestoreCommand
        {
            get;
        }

        #endregion

        #region · Properties ·

        /// <summary>
        /// Gets the navigation route
        /// </summary>
        string NavigationRoute
        {
            get;
        }

        /// <summary>
        /// Gets a value indicating wheter the viewmodel has available relations
        /// </summary>
        bool HasRelations
        {
            get;
        }

        #endregion
    }
}
