﻿/*
The MIT License

Copyright (c) 2009-2010. Carlos Guzmán Álvarez. http://chronoswpf.codeplex.com/

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

using System;
using Chronos.Presentation.Core.Windows;
using nRoute.Components;

namespace Chronos.Presentation.Core.ViewModel
{
    /// <summary>
    /// Interface for workspace viewmodel implementations
    /// </summary>
    /// <typeparam name="TEntity"></typeparam>
    public interface IWorkspaceViewModel<TEntity>
        : IWindowViewModel, IEntityViewModel<TEntity>, INavigationViewModel, IBookmarkViewModel where TEntity : class, new()
    {
        #region · Events ·

        /// <summary>
        /// Occurs when the view mode has changed
        /// </summary>
        event EventHandler ViewModeChanged;

        #endregion

        #region · Commands ·

        /// <summary>
        /// Gets the add new command
        /// </summary>
        ActionCommand AddNewCommand
        {
            get;
        }

        /// <summary>
        /// Gets the delete command
        /// </summary>
        ActionCommand DeleteCommand
        {
            get;
        }

        /// <summary>
        /// Gets the discard changes command
        /// </summary>
        ActionCommand DiscardCommand
        {
            get;
        }

        /// <summary>
        /// Gets the edit command
        /// </summary>
        ActionCommand EditCommand
        {
            get;
        }

        /// <summary>
        /// Gets the save changes command
        /// </summary>
        ActionCommand SaveCommand
        {
            get;
        }

        /// <summary>
        /// Gets the print command
        /// </summary>
        ActionCommand PrintCommand
        {
            get;
        }

        /// <summary>
        /// Gets the print preview command
        /// </summary>
        ActionCommand PrintPreviewCommand
        {
            get;
        }

        /// <summary>
        /// Gets the show form help command
        /// </summary>
        ActionCommand ShowFormHelpCommand
        {
            get;
        }

        /// <summary>
        /// Gets the show zoom window command
        /// </summary>
        ActionCommand ShowZoomWindowCommand
        {
            get;
        }

        #endregion

        #region · Properties ·

        /// <summary>
        /// Gets or sets a value indicating whether the zoom window is shown
        /// </summary>
        bool ShowZoomWindow
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the zoom level
        /// </summary>
        double ZoomLevel
        {
            get;
            set;
        }

        #endregion
   }
}
