﻿/*
The MIT License

Copyright (c) 2009-2010. Carlos Guzmán Álvarez. http://chronoswpf.codeplex.com/

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Chronos.Presentation.Core.ViewModel
{
    /// <summary>
    /// Event argument for the currentchanged eventhandler
    /// </summary>
    /// <typeparam name="T"></typeparam>
    /// <typeparam name="V"></typeparam>
    public sealed class ItemChangedEventArgs<T, V> 
        : EventArgs
    {
        #region · Properties ·

        /// <summary>
        /// Gets or sets the current item.
        /// </summary>
        /// <value>The current item.</value>
        public T Item
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets or sets the current viewmodel.
        /// </summary>
        /// <value>The current viewmodel.</value>
        public V ItemViewModel
        {
            get;
            private set;
        }

        #endregion
        
        #region · Constructors ·

        /// <summary>
        /// Initializes a new instance of the <see cref="ItemChangedArgs&lt;T, V&gt;"/> class.
        /// </summary>
        /// <param name="currentItem">The current item.</param>
        /// <param name="currentViewModel">The current viewmodel.</param>
        public ItemChangedEventArgs(T item, V itemViewModel)
            : base()
        {
            this.Item           = item;
            this.ItemViewModel  = itemViewModel;
        }

        #endregion
    }
}
