﻿/*
The MIT License

Copyright (c) 2009-2010. Carlos Guzmán Álvarez. http://chronoswpf.codeplex.com/

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

using System;
using System.Windows.Controls;

namespace Chronos.Presentation.Core.Windows
{
    /// <summary>
    /// Interface for desktop element implementations
    /// </summary>
    public interface IDesktopElement
    {
        #region · Properties ·

        /// <summary>
        /// Gets the element identifier
        /// </summary>
        Guid Id
        {
            get;
        }

        /// <summary>
        /// Gets the element parent
        /// </summary>
        Panel Parent
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets a value indicating whether the element can be dragged
        /// </summary>
        bool CanDrag
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets a value indicating whether the element can be resized
        /// </summary>
        bool CanResize
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the element <see cref="Chronos.Presentation.Core.Windows.StartupPosition"/>
        /// </summary>
        StartupPosition StartupLocation
        {
            get;
            set;
        }

        #endregion

        #region · Methods ·

        /// <summary>
        /// Activates the element
        /// </summary>
        void Activate();

        #endregion
    }
}
