﻿/*
The MIT License

Copyright (c) 2009-2010. Carlos Guzmán Álvarez. http://chronoswpf.codeplex.com/

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

using System;
using System.ComponentModel;
using System.Windows;
using System.Windows.Input;

namespace Chronos.Presentation.Core.Windows
{
    /// <summary>
    /// 
    /// </summary>
    public interface IWindow 
        : IDesktopElement
    {
        #region · Events ·

        /// <summary>
        /// Occurs when the window state has changed
        /// </summary>
        event EventHandler WindowStateChanged;

        /// <summary>
        /// Occurs when the window is about to be closed
        /// </summary>
        event CancelEventHandler Closing;

        /// <summary>
        /// Occurs when the window is closed
        /// </summary>
        event EventHandler Closed;

        #endregion

        #region · Commands ·

        /// <summary>
        /// Gets the close window command
        /// </summary>
        ICommand CloseCommand
        {
            get;
        }

        /// <summary>
        /// Gets the maximize window command
        /// </summary>
        ICommand MaximizeCommand
        {
            get;
        }

        /// <summary>
        /// Gets the minimize window command
        /// </summary>
        ICommand MinimizeCommand
        {
            get;
        }

        #endregion

        #region · Properties ·

        /// <summary>
        /// Gets or sets the window title
        /// </summary>
        string Title
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets a value that indicates whether the maximize button is shown
        /// </summary>
        bool ShowMaximizeButton
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets a value that indicates whether the minimize button is shown
        /// </summary>
        bool ShowMinimizeButton
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets a value that indicates whether the close button is shown
        /// </summary>
        bool ShowCloseButton
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the current <see cref="Chronos.Presentation.Core.Windows.ViewModeType"/>
        /// </summary>
        ViewModeType ViewMode
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the <see cref="Chronos.Presentation.Core.Windows.WindowState"/>
        /// </summary>
        WindowState WindowState
        {
            get;
            set;
        }

        #endregion

        #region · Methods ·

        /// <summary>
        /// Shows the window
        /// </summary>
        void Show();

        /// <summary>
        /// Closes the window
        /// </summary>
        void Close();

        /// <summary>
        /// Hides the window
        /// </summary>
        void Hide();

        #endregion
    }
}
