﻿/*
The MIT License

Copyright (c) 2009-2010. Carlos Guzmán Álvarez. http://chronoswpf.codeplex.com/

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

using System.ComponentModel;
using nRoute.Services;
using nRoute.ViewServices;

namespace Chronos.Presentation.ViewModel
{
    /// <summary>
    /// Provides a base class for Applications to inherit from. 
    /// </summary>
    public abstract class ViewModelBase 
        : ObservableObject
    {
        #region · Constructors ·

        /// <summary>
        /// Initializes a new instance of the <see cref="ViewModelBase"/> class.
        /// </summary>
        protected ViewModelBase()
            : base()
        {
        }

        #endregion

        #region · Protected Methods ·

        /// <summary>
        /// Gets the requested service instance.
        /// </summary>
        /// <typeparam name="TService">The type of the service.</typeparam>
        /// <returns></returns>
        protected TService GetService<TService>() where TService : class
        {
            return ServiceLocator.GetService<TService>();
        }

        /// <summary>
        /// Gets the requested view service.
        /// </summary>
        /// <typeparam name="TViewService">The type of the view service.</typeparam>
        /// <returns></returns>
        protected TViewService GetViewService<TViewService>() where TViewService : class
        {
            return ViewServiceLocator.GetViewService<TViewService>();
        }

        #endregion
    }
}
