﻿/*
The MIT License

Copyright (c) 2009-2010. Carlos Guzmán Álvarez. http://chronoswpf.codeplex.com/

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

using System.Windows.Input;
using Chronos.Presentation.Core.VirtualDesktops;
using Chronos.Presentation.Core.Widgets;
using Chronos.Presentation.Core.Windows;
using Chronos.Presentation.ViewModel;
using nRoute.Components;

namespace Chronos.WidgetLibrary
{
    /// <summary>
    /// Widget Definition ViewModel
    /// </summary>
    public sealed class WidgetItemViewModel
        : ViewModelBase, IWidget
    {
        #region · Fields ·

        private IWidget     widgetDefinition;
        private ICommand    createWidgetCommand;

        #endregion

        #region · Commands ·

        /// <summary>
        /// Gets the create widget command.
        /// </summary>
        /// <value>The create widget command.</value>
        public ICommand CreateWidgetCommand
        {
            get
            {
                if (this.createWidgetCommand == null)
                {
                    this.createWidgetCommand = new ActionCommand(() => OnCreateWidget());
                }

                return this.createWidgetCommand;
            }
        }

        #endregion

        #region · Properties ·

        /// <summary>
        /// Gets the widget title
        /// </summary>
        /// <value></value>
        public string Title
        {
            get { return this.widgetDefinition.Title; }
        }

        /// <summary>
        /// Gets the widget description
        /// </summary>
        /// <value></value>
        public string Description
        {
            get { return this.widgetDefinition.Description; }
        }

        /// <summary>
        /// Gets the widget group
        /// </summary>
        /// <value></value>
        public string Group
        {
            get { return this.widgetDefinition.Group; }
        }

        /// <summary>
        /// Gets the widget icon style
        /// </summary>
        /// <value></value>
        public string IconStyle
        {
            get { return this.widgetDefinition.IconStyle; }
        }

        #endregion

        #region · Constructors ·

        /// <summary>
        /// Initializes a new instance of the <see cref="WidgetItemViewModel"/> class.
        /// </summary>
        /// <param name="widget">The widget.</param>
        public WidgetItemViewModel(IWidget widgetDefinition)
            : base()
        {
            this.widgetDefinition = widgetDefinition;
        }

        #endregion

        #region · IWidget Members ·

        /// <summary>
        /// Creates the widget view
        /// </summary>
        /// <returns></returns>
        System.Windows.FrameworkElement IWidget.CreateView()
        {
            return this.widgetDefinition.CreateView();
        }

        #endregion

        #region · Command Actions ·

        /// <summary>
        /// Handles the create widget command.
        /// </summary>
        private void OnCreateWidget()
        {
            this.GetService<IVirtualDesktopManager>()
                .Show(this.widgetDefinition.CreateView() as IDesktopElement);
        }

        #endregion
    }
}
